@@ -68,6 +68,7 @@ fi
 
 POINTER_BASENAME="${MODEL_POINTER_BASENAME:-current_session.txt}"
 ACTIVE_SESSION_BASENAME="${MODEL_ACTIVE_SESSION_BASENAME:-active_session_id.txt}"
+LOCK_BASENAME="${MODEL_LOCK_BASENAME:-worker.lock}"
 
 graceful_shutdown_claudecode() {
   local session="$1"
@@ -134,7 +135,7 @@ kill_tty_sessions() {
 
 clear_session_files() {
   local log_dir="$1"
-  rm -f "$log_dir/$POINTER_BASENAME" "$log_dir/$ACTIVE_SESSION_BASENAME"
+  rm -f "$log_dir/$POINTER_BASENAME" "$log_dir/$ACTIVE_SESSION_BASENAME" "$log_dir/$LOCK_BASENAME"
 }
 
 kill_pid_file() {
