@@ -1,11 +1,11 @@
-"""aiogram FSM state definitions."""
+"""aiogram FSM 状态定义。"""
 from __future__ import annotations
 
 from aiogram.fsm.state import State, StatesGroup
 
 
 class TaskCreateStates(StatesGroup):
-    """States for the guided task creation flow."""
+    """任务创建引导流程的状态集。"""
 
     waiting_title = State()
     waiting_type = State()
@@ -14,7 +14,7 @@ class TaskCreateStates(StatesGroup):
 
 
 class TaskEditStates(StatesGroup):
-    """States for editing existing tasks."""
+    """任务编辑流程的状态集。"""
 
     waiting_task_id = State()
     waiting_field_choice = State()
@@ -23,7 +23,7 @@ class TaskEditStates(StatesGroup):
 
 
 class TaskNoteStates(StatesGroup):
-    """States for appending notes to a task."""
+    """任务备注追加流程的状态集。"""
 
     waiting_task_id = State()
     waiting_content = State()
@@ -31,7 +31,7 @@ class TaskNoteStates(StatesGroup):
 
 
 class TaskBugReportStates(StatesGroup):
-    """States for the defect reporting flow."""
+    """缺陷报告流程状态。"""
 
     waiting_description = State()
     waiting_reproduction = State()
@@ -40,26 +40,26 @@ class TaskBugReportStates(StatesGroup):
 
 
 class TaskDescriptionStates(StatesGroup):
-    """States for editing task descriptions."""
+    """任务描述编辑流程状态。"""
 
     waiting_content = State()
     waiting_confirm = State()
 
 
 class TaskPushStates(StatesGroup):
-    """States for sending supplemental task updates."""
+    """任务推送补充信息流程的状态集。"""
 
     waiting_choice = State()
     waiting_supplement = State()
 
 
 class TaskListSearchStates(StatesGroup):
-    """States for searching within the task list."""
+    """任务列表搜索流程的状态集。"""
 
     waiting_keyword = State()
 
 
 class ProjectDeleteStates(StatesGroup):
-    """States for confirming master project deletion."""
+    """Master 项目删除确认流程的状态定义。"""
 
     confirming = State()
