@@ -1,4 +1,4 @@
-"""Allow executing the CLI via ``python -m vibego_cli``."""
+"""允许通过 `python -m vibego_cli` 直接调用 CLI。"""
 
 from __future__ import annotations
 
@@ -6,3 +6,4 @@ from . import main
 
 if __name__ == "__main__":
     main()
+
