@@ -1,4 +1,4 @@
-"""Shared configuration and path utilities for the vibego CLI."""
+"""vibego CLI 通用配置与路径解析工具。"""
 
 from __future__ import annotations
 
@@ -10,10 +10,10 @@ from typing import Dict
 
 
 def _default_config_root() -> Path:
-    """Return the default configuration root following the XDG Base Directory spec.
+    """计算默认配置根目录，遵循 XDG Base Directory 规范。
 
-    The function prefers the ``VIBEGO_CONFIG_DIR`` environment variable and falls
-    back to ``~/.config/vibego`` when not provided.
+    优先读取环境变量 `VIBEGO_CONFIG_DIR`，否则采用
+    `~/.config/vibego`。
     """
 
     override = os.environ.get("VIBEGO_CONFIG_DIR")
@@ -44,7 +44,7 @@ LOG_FILE: Path = LOG_DIR / "vibe.log"
 
 
 def ensure_worker_requirements_copy() -> Path:
-    """Ensure the runtime directory contains a fresh copy of worker dependencies."""
+    """确保运行目录内存在 worker 依赖清单副本并返回其路径。"""
 
     source = resources.files("vibego_cli").joinpath("data/worker_requirements.txt")
     target = RUNTIME_DIR / "worker_requirements.txt"
@@ -57,14 +57,14 @@ def ensure_worker_requirements_copy() -> Path:
 
 
 def ensure_directories() -> None:
-    """Create every directory required by the CLI if it does not exist."""
+    """保证 CLI 运行所需的目录全部存在。"""
 
     for path in (CONFIG_ROOT, CONFIG_DIR, LOG_DIR, STATE_DIR, DATA_DIR, RUNTIME_DIR):
         path.mkdir(parents=True, exist_ok=True)
 
 
 def parse_env_file(path: Path) -> Dict[str, str]:
-    """Parse a simple ``KEY=VALUE`` style ``.env`` file."""
+    """解析简单的 KEY=VALUE 形式的 .env 文件。"""
 
     if not path.exists():
         return {}
@@ -81,12 +81,12 @@ def parse_env_file(path: Path) -> Dict[str, str]:
 
 
 def dump_env_file(path: Path, values: Dict[str, str]) -> None:
-    """Write a ``.env`` file and enforce permission ``600`` when possible."""
+    """写入 .env 文件，确保文件权限为 600。"""
 
     lines = [f"{key}={value}" for key, value in sorted(values.items())]
     path.write_text("\n".join(lines) + "\n", encoding="utf-8")
     try:
         path.chmod(stat.S_IRUSR | stat.S_IWUSR)
     except PermissionError:
-        # Some platforms (e.g., Windows) may not allow chmod; ignore the failure.
+        # 在部分平台（例如 Windows）可能无法调整权限，忽略即可。
         pass
